"""Framework integration extras for asqav.

Install specific extras:
    pip install asqav[langchain]
    pip install asqav[crewai]
    pip install asqav[litellm]
    pip install asqav[haystack]
    pip install asqav[openai-agents]
    pip install asqav[all]
"""
